==> aisleriot-3.14.2p1.tgz: lib/aisleriot/guile/2.0/aunt-mary.go <==
GOOF----BE-4-2.0  
_    ] , 4  h  @    ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
g  api	
 	 	
g  primitive-load-path	f  klondike	g  deal-one	g  
deal-three	g  	no-redeal	g  
max-redeal							
	 	g  tableau	g  initialize-playing-area	g  set-ace-low	g  make-standard-deck	g  shuffle-deck	g  add-normal-slot	g  DECK	g  stock	g  add-partially-extended-slot	g  right	g  waste	g  
foundation	 g  add-carriage-return-slot	!g  add-extended-slot	"g  down	#g  
deal-cards	$					
					
				
		
		 	%g  deal-cards-face-up	&																	
						
	 	'g  give-status-message	(g  new-game	)g  get-options	*g  
apply-options	+g  set-lambda!C 5   h     ] 4	 >  "  G  4
i>  "  G  RRR	RR !"#$%&'     h    ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  $  4	
	>  "  G  "  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4
>   "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>   "  G  		 C          g  filenamef  
aunt-mary.scm
	
							#	!		3	"		C	%		I	%		N	%		\	'		]	(		`	(	#	f	(	/	k	(		x	)		{	)		}	)	 	)	 	,	 	,	 	,	 	,	 	-	 	-	 	-	 	-	 	.	 	.	 	.	 	.	 	/	 	/	 	/	 	/	 	0	 	2	 	2	 	2	 	2	 	3	 	3		3		3		4		4		4		4	&	5	)	5	-	5	2	5	;	6	>	6	B	6	G	6	P	7	S	7	W	7	\	7	e	:	k	;	p	:	y	@		A		@		H		J	 C	
  g  nameg  new-game C(R    h      W] C       O    g  filenamef  
aunt-mary.scm
	M
 		
  g  nameg  get-options C)R    h      o]C       g    g  options
		  g  filenamef  
aunt-mary.scm
	P
 		  g  nameg  
apply-options C*R4+i((i>  "  G  4+i))i>  "  G  +i**i6         g  filenamef  
aunt-mary.scm		
		
	 			%	
	1	
	5	
	9	
	>	
	@			C	
	
*	M
	P
	S
	S	
	S
	T
	T	
	T
	U	
	U
 	
   C6 

==> aisleriot-3.18.2.tgz: lib/aisleriot/guile/2.0/aunt-mary.go <==
GOOF----LE-8-2.0_
      ] , 4  h@      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
g  api	
 	 	
g  primitive-load-path	f  klondike	g  deal-one	g  
deal-three	g  	no-redeal	g  
max-redeal							
	 	g  tableau	g  initialize-playing-area	g  set-ace-low	g  make-standard-deck	g  shuffle-deck	g  add-normal-slot	g  DECK	g  stock	g  add-partially-extended-slot	g  right	g  waste	g  
foundation	 g  add-carriage-return-slot	!g  add-extended-slot	"g  down	#g  
deal-cards	$					
					
				
		
		 	%g  deal-cards-face-up	&																	
						
	 	'g  give-status-message	(g  new-game	)g  get-options	*g  
apply-options	+g  set-lambda!C 5   h     ] 4	 >  "  G  4
i>  "  G  RRR	RR !"#$%&'     h    ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  $  4	
	>  "  G  "  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4
>   "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>   "  G  		 C          g  filenamef  
aunt-mary.scm
	
							#	!		3	"		C	%		I	%		N	%		\	'		]	(		`	(	#	f	(	/	k	(		x	)		{	)		}	)	 	)	 	,	 	,	 	,	 	,	 	-	 	-	 	-	 	-	 	.	 	.	 	.	 	.	 	/	 	/	 	/	 	/	 	0	 	2	 	2	 	2	 	2	 	3	 	3		3		3		4		4		4		4	&	5	)	5	-	5	2	5	;	6	>	6	B	6	G	6	P	7	S	7	W	7	\	7	e	:	k	;	p	:	y	@		A		@		H		J	 C	
  g  nameg  new-game C(R    h   W   ] C    O       g  filenamef  
aunt-mary.scm
	M
 		
  g  nameg  get-options C)R    h   o   ]C    g       g  options
		  g  filenamef  
aunt-mary.scm
	P
 		  g  nameg  
apply-options C*R4+i((i>  "  G  4+i))i>  "  G  +i**i6         g  filenamef  
aunt-mary.scm		
		
	 			%	
	1	
	5	
	9	
	>	
	@			C	
	
*	M
	P
	S
	S	
	S
	T
	T	
	T
	U	
	U
 	
   C6 
